==> task-3.30.1.tar.gz: task-3.30.1/docs/i18n/ja-JP/docusaurus-plugin-content-docs/current/donate.md <==
---
slug: /donate/
sidebar_position: 16
---

# 寄付

If you find this project useful, you can consider donating by using one of the channels listed below.

This is just a way of saying "thank you", it won't give you any benefits like higher priority on issues or something similar.

Companies who donate at least $50/month will be featured as a "Gold Sponsor" in the website homepage and on the GitHub repository README. Make contact with [@andreynering][] with the logo you want to be shown. Suspect businesses (gambling, casinos, etc) won't be allowed, though.

## GitHub Sponsors

The preferred way to donate to the maintainers is via GitHub Sponsors. Just use the following links to do your donation:

- [@andreynering](https://github.com/sponsors/andreynering)
- [@pd93](https://github.com/sponsors/pd93)

## Open Collective

If you prefer [Open Collective](https://opencollective.com/task) you can donate by using these links:

- [$2 per month](https://opencollective.com/task/contribute/backer-4034/checkout)
- [$5 per month](https://opencollective.com/task/contribute/supporter-8404/checkout)
- [$20 per month](https://opencollective.com/task/contribute/sponsor-4035/checkout)
- [$50 per month](https://opencollective.com/task/contribute/sponsor-28775/checkout)
- [Custom value - One-time donation option supported](https://opencollective.com/task/donate)

## PayPal

You can donate to [@andreynering][] via PayPal as well:

- [Any value - One-time donation](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=GSVDU63RKG45A&currency_code=USD&source=url)

## PIX (ブラジルのみ)

And if you're Brazilian, you can also donate to [@andreynering][] via PIX by [using this QR Code](/img/pix.png).

<!-- prettier-ignore-start -->

<!-- prettier-ignore-end -->
[@andreynering]: https://github.com/andreynering

==> task-3.34.1.tar.gz: task-3.34.1/docs/i18n/ja-JP/docusaurus-plugin-content-docs/current/donate.md <==
---
slug: /donate/
sidebar_position: 16
---

# 寄付

If you find this project useful, you can consider donating by using one of the channels listed below.

This is just a way of saying "thank you", it won't give you any benefits like higher priority on issues or something similar.

Companies who donate at least $50/month will be featured as a "Gold Sponsor" in the website homepage and on the GitHub repository README. Make contact with [@andreynering][] with the logo you want to be shown. Suspect businesses (gambling, casinos, etc) won't be allowed, though.

## GitHub Sponsors

The preferred way to donate to the maintainers is via GitHub Sponsors. Just use the following links to do your donation. We suggest a 50/50 split to each maintainer of the total amount you plan to donate to the project.

- [@andreynering](https://github.com/sponsors/andreynering)
- [@pd93](https://github.com/sponsors/pd93)

## Open Collective

If you prefer [Open Collective](https://opencollective.com/task) you can donate by using these links:

- [$2 per month](https://opencollective.com/task/contribute/backer-4034/checkout)
- [$5 per month](https://opencollective.com/task/contribute/supporter-8404/checkout)
- [$20 per month](https://opencollective.com/task/contribute/sponsor-4035/checkout)
- [$50 per month](https://opencollective.com/task/contribute/sponsor-28775/checkout)
- [Custom value - One-time donation option supported](https://opencollective.com/task/donate)

## PayPal

You can donate to [@andreynering][] via PayPal as well:

- [Any value - One-time donation](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=GSVDU63RKG45A&currency_code=USD&source=url)

## PIX (ブラジルのみ)

And if you're Brazilian, you can also donate to [@andreynering][] via PIX by [using this QR Code](/img/pix.png).

<!-- prettier-ignore-start -->

<!-- prettier-ignore-end -->
[@andreynering]: https://github.com/andreynering
